@@ -30,10 +30,12 @@ from .cache import RootBankCache as RootBankCache
 from .client import BetterClient as BetterClient
 from .client import BlockhashNotFoundException as BlockhashNotFoundException
 from .client import ClientException as ClientException
-from .client import CompatibleClient as CompatibleClient
+from .client import CompoundRPCCaller as CompoundRPCCaller
 from .client import FailedToFetchBlockhashException as FailedToFetchBlockhashException
 from .client import NodeIsBehindException as NodeIsBehindException
 from .client import RateLimitException as RateLimitException
+from .client import RPCCaller as RPCCaller
+from .client import SlotHolder as SlotHolder
 from .client import TooManyRequestsRateLimitException as TooManyRequestsRateLimitException
 from .client import TooMuchBandwidthRateLimitException as TooMuchBandwidthRateLimitException
 from .client import TransactionException as TransactionException
@@ -188,6 +190,8 @@ from .spotmarket import SpotMarket as SpotMarket
 from .spotmarket import SpotMarketStub as SpotMarketStub
 from .spotmarketoperations import SpotMarketInstructionBuilder as SpotMarketInstructionBuilder
 from .spotmarketoperations import SpotMarketOperations as SpotMarketOperations
+from .text import indent_collection_as_str as indent_collection_as_str
+from .text import indent_item_by as indent_item_by
 from .token import Instrument as Instrument
 from .token import SolToken as SolToken
 from .token import Token as Token
